==> ejc-settle-impl-3.0.0-20240607.062047-14-sources.jar: com/ejianc/business/settle/bean/SettlementCenterDcDrwgrpInfoEntity.java <==
package com.ejianc.business.settle.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 结算中心卷册信息表
 * 
 * @author generator
 * 
 */
 @TableName("settlement_center_dc_drwgrp_info")
public class SettlementCenterDcDrwgrpInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="contract_id")
    private Long contractId; // 承包合同id
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="dc_drwgrp_info_id")
    private Long dcDrwgrpInfoId; // 卷册主键id
    @TableField(value="budge_id")
    private Long budgeId; // 预算书id
    @TableField(value="settlement_center_major")
    private Long settlementCenterMajor; // 结算中心专业
    @TableField(value="statistical_output")
    private BigDecimal statisticalOutput; // 统计产值
    @TableField(value="discriminate_state")
    private Long discriminateState; // 图纸类别
    @TableField(value="first_node_time")
    private Date firstNodeTime; // 数据生成的时间
    @TableField(value="second_node_time")
    private Date secondNodeTime; // 综合管理员派发时间
    @TableField(value="third_node_time")
    private Date thirdNodeTime; // 结算中心项目负责人派发时间
    @TableField(value="fourth_node_time")
    private Date fourthNodeTime; // 结算中心专职提交时间
    @TableField(value="fifth_node_time")
    private Date fifthNodeTime; // 专业主管审核时间
    @TableField(value="sixth_node_time")
    private Date sixthNodeTime; // 结算中心项目负责人复审时间
    @TableField(value="seventh_node_time")
    private Date seventhNodeTime; // 项目合同主管复审时间
    @TableField(value="first_node_user_id")
    private Long firstNodeUserId; // 节点1综合管理员
    @TableField(value="second_node_user_id")
    private Long secondNodeUserId; // 节点2结算中心项目负责人
    @TableField(value="third_node_user_id")
    private Long thirdNodeUserId; // 节点3结算中心专职
    @TableField(value="fourth_node_user_id")
    private Long fourthNodeUserId; // 节点4专业主管
    @TableField(value="fifth_node_user_id")
    private Long fifthNodeUserId; // 节点5结算中心项目负责人
    @TableField(value="sixth_node_user_id")
    private Long sixthNodeUserId; // 节点6项目合同主管
    @TableField(value="seventh_node_user_id")
    private Long seventhNodeUserId; // 节点7综合管理员
    @TableField(value="create_dept_id")
    private Long createDeptId; // 创建部门id
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 所属组织id
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 所属组织名称
    @TableField(value="engineering_type_id")
    private Long engineeringTypeId; // 工程类别
    @TableField(value="subitem")
    private Long subitem; // 子项--字典zx
    @TableField(value="subitem_name")
    private String subitemName; // 子项名称
    @TableField(value="flow_state")
    private String flowState; // 流程状态
    @TableField(value="flow_state_name")
    private String flowStateName; // 流程状态名称
    @TableField(value="desired_time")
    private Date desiredTime; // 期望完成时间
    @TableField(value="eighth_node_time")
    private Date eighthNodeTime; // 综合管理员复审归档时间
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="dc_drwgrp_info_code")
    private String dcDrwgrpInfoCode; // 卷册编码
    @TableField(value="contract_code")
    private String contractCode;//承包合同code
    @TableField(value="whether_upgrade")
    private Integer whetherUpgrade;//是否升版文件(0 否 1 是)
    @TableField(value="dc_drwgrp_info_name")
    private String dcDrwgrpInfoName; // 卷册名称
    
    
    

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getDcDrwgrpInfoId() {
        return dcDrwgrpInfoId;
    }

    public void setDcDrwgrpInfoId(Long dcDrwgrpInfoId) {
        this.dcDrwgrpInfoId = dcDrwgrpInfoId;
    }
    public Long getBudgeId() {
        return budgeId;
    }

    public void setBudgeId(Long budgeId) {
        this.budgeId = budgeId;
    }
    public Long getSettlementCenterMajor() {
        return settlementCenterMajor;
    }

    public void setSettlementCenterMajor(Long settlementCenterMajor) {
        this.settlementCenterMajor = settlementCenterMajor;
    }
    public BigDecimal getStatisticalOutput() {
        return statisticalOutput;
    }

    public void setStatisticalOutput(BigDecimal statisticalOutput) {
        this.statisticalOutput = statisticalOutput;
    }
    public Long getDiscriminateState() {
        return discriminateState;
    }

    public void setDiscriminateState(Long discriminateState) {
        this.discriminateState = discriminateState;
    }
    public Date getFirstNodeTime() {
        return firstNodeTime;
    }

    public void setFirstNodeTime(Date firstNodeTime) {
        this.firstNodeTime = firstNodeTime;
    }
    public Date getSecondNodeTime() {
        return secondNodeTime;
    }

    public void setSecondNodeTime(Date secondNodeTime) {
        this.secondNodeTime = secondNodeTime;
    }
    public Date getThirdNodeTime() {
        return thirdNodeTime;
    }

    public void setThirdNodeTime(Date thirdNodeTime) {
        this.thirdNodeTime = thirdNodeTime;
    }
    public Date getFourthNodeTime() {
        return fourthNodeTime;
    }

    public void setFourthNodeTime(Date fourthNodeTime) {
        this.fourthNodeTime = fourthNodeTime;
    }
    public Date getFifthNodeTime() {
        return fifthNodeTime;
    }

    public void setFifthNodeTime(Date fifthNodeTime) {
        this.fifthNodeTime = fifthNodeTime;
    }
    public Date getSixthNodeTime() {
        return sixthNodeTime;
    }

    public void setSixthNodeTime(Date sixthNodeTime) {
        this.sixthNodeTime = sixthNodeTime;
    }
    public Date getSeventhNodeTime() {
        return seventhNodeTime;
    }

    public void setSeventhNodeTime(Date seventhNodeTime) {
        this.seventhNodeTime = seventhNodeTime;
    }
    public Long getFirstNodeUserId() {
        return firstNodeUserId;
    }

    public void setFirstNodeUserId(Long firstNodeUserId) {
        this.firstNodeUserId = firstNodeUserId;
    }
    public Long getSecondNodeUserId() {
        return secondNodeUserId;
    }

    public void setSecondNodeUserId(Long secondNodeUserId) {
        this.secondNodeUserId = secondNodeUserId;
    }
    public Long getThirdNodeUserId() {
        return thirdNodeUserId;
    }

    public void setThirdNodeUserId(Long thirdNodeUserId) {
        this.thirdNodeUserId = thirdNodeUserId;
    }
    public Long getFourthNodeUserId() {
        return fourthNodeUserId;
    }

    public void setFourthNodeUserId(Long fourthNodeUserId) {
        this.fourthNodeUserId = fourthNodeUserId;
    }
    public Long getFifthNodeUserId() {
        return fifthNodeUserId;
    }

    public void setFifthNodeUserId(Long fifthNodeUserId) {
        this.fifthNodeUserId = fifthNodeUserId;
    }
    public Long getSixthNodeUserId() {
        return sixthNodeUserId;
    }

    public void setSixthNodeUserId(Long sixthNodeUserId) {
        this.sixthNodeUserId = sixthNodeUserId;
    }
    public Long getSeventhNodeUserId() {
        return seventhNodeUserId;
    }

    public void setSeventhNodeUserId(Long seventhNodeUserId) {
        this.seventhNodeUserId = seventhNodeUserId;
    }
    public Long getCreateDeptId() {
        return createDeptId;
    }

    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    public Long getSubitem() {
        return subitem;
    }

    public void setSubitem(Long subitem) {
        this.subitem = subitem;
    }
    public String getSubitemName() {
        return subitemName;
    }

    public void setSubitemName(String subitemName) {
        this.subitemName = subitemName;
    }
    public String getFlowState() {
        return flowState;
    }

    public void setFlowState(String flowState) {
        this.flowState = flowState;
    }
    public String getFlowStateName() {
        return flowStateName;
    }

    public void setFlowStateName(String flowStateName) {
        this.flowStateName = flowStateName;
    }
    public Date getDesiredTime() {
        return desiredTime;
    }

    public void setDesiredTime(Date desiredTime) {
        this.desiredTime = desiredTime;
    }

    public Date getEighthNodeTime() {
        return eighthNodeTime;
    }

    public void setEighthNodeTime(Date eighthNodeTime) {
        this.eighthNodeTime = eighthNodeTime;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getDcDrwgrpInfoCode() {
        return dcDrwgrpInfoCode;
    }

    public void setDcDrwgrpInfoCode(String dcDrwgrpInfoCode) {
        this.dcDrwgrpInfoCode = dcDrwgrpInfoCode;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public Integer getWhetherUpgrade() {
        return whetherUpgrade;
    }

    public void setWhetherUpgrade(Integer whetherUpgrade) {
        this.whetherUpgrade = whetherUpgrade;
    }

    public String getDcDrwgrpInfoName() {
        return dcDrwgrpInfoName;
    }

    public void setDcDrwgrpInfoName(String dcDrwgrpInfoName) {
        this.dcDrwgrpInfoName = dcDrwgrpInfoName;
    }
}

==> ejc-settle-impl-3.0.0-20240617.022532-42-sources.jar: com/ejianc/business/settle/bean/SettlementCenterDcDrwgrpInfoEntity.java <==
package com.ejianc.business.settle.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 结算中心卷册信息表
 * 
 * @author generator
 * 
 */
 @TableName("settlement_center_dc_drwgrp_info")
public class SettlementCenterDcDrwgrpInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="contract_id")
    private Long contractId; // 承包合同id
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="dc_drwgrp_info_id")
    private Long dcDrwgrpInfoId; // 卷册主键id
    @TableField(value="budge_id")
    private Long budgeId; // 预算书id
    @TableField(value="settlement_center_major")
    private Long settlementCenterMajor; // 结算中心专业
    @TableField(value="statistical_output")
    private BigDecimal statisticalOutput; // 统计产值
    @TableField(value="discriminate_state")
    private Long discriminateState; // 图纸类别
    @TableField(value="first_node_time")
    private Date firstNodeTime; // 数据生成的时间
    @TableField(value="second_node_time")
    private Date secondNodeTime; // 综合管理员派发时间
    @TableField(value="third_node_time")
    private Date thirdNodeTime; // 结算中心项目负责人派发时间
    @TableField(value="fourth_node_time")
    private Date fourthNodeTime; // 结算中心专职提交时间
    @TableField(value="fifth_node_time")
    private Date fifthNodeTime; // 专业主管审核时间
    @TableField(value="sixth_node_time")
    private Date sixthNodeTime; // 结算中心项目负责人复审时间
    @TableField(value="seventh_node_time")
    private Date seventhNodeTime; // 项目合同主管复审时间
    @TableField(value="first_node_user_id")
    private Long firstNodeUserId; // 节点1综合管理员
    @TableField(value="second_node_user_id")
    private Long secondNodeUserId; // 节点2结算中心项目负责人
    @TableField(value="third_node_user_id")
    private Long thirdNodeUserId; // 节点3结算中心专职
    @TableField(value="fourth_node_user_id")
    private Long fourthNodeUserId; // 节点4专业主管
    @TableField(value="fifth_node_user_id")
    private Long fifthNodeUserId; // 节点5结算中心项目负责人
    @TableField(value="sixth_node_user_id")
    private Long sixthNodeUserId; // 节点6项目合同主管
    @TableField(value="seventh_node_user_id")
    private Long seventhNodeUserId; // 节点7综合管理员
    @TableField(value="first_node_user_name")
    private String firstNodeUserName; // 节点1综合管理员
    @TableField(value="second_node_user_name")
    private String secondNodeUserName; // 节点2结算中心项目负责人
    @TableField(value="third_node_user_name")
    private String thirdNodeUserName; // 节点3结算中心专职
    @TableField(value="fourth_node_user_name")
    private String fourthNodeUserName; // 节点4专业主管
    @TableField(value="fifth_node_user_name")
    private String fifthNodeUserName; // 节点5结算中心项目负责人
    @TableField(value="sixth_node_user_name")
    private String sixthNodeUserName; // 节点6项目合同主管
    @TableField(value="seventh_node_user_name")
    private String seventhNodeUserName; // 节点7综合管理员
    @TableField(value="create_dept_id")
    private Long createDeptId; // 创建部门id
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 所属组织id
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 所属组织名称
    @TableField(value="engineering_type_id")
    private Long engineeringTypeId; // 工程类别
    @TableField(value="subitem")
    private Long subitem; // 子项--字典zx
    @TableField(value="subitem_name")
    private String subitemName; // 子项名称
    @TableField(value="flow_state")
    private String flowState; // 流程状态
    @TableField(value="flow_state_name")
    private String flowStateName; // 流程状态名称
    @TableField(value="desired_time")
    private Date desiredTime; // 期望完成时间
    @TableField(value="eighth_node_time")
    private Date eighthNodeTime; // 综合管理员复审归档时间
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="dc_drwgrp_info_code")
    private String dcDrwgrpInfoCode; // 卷册编码
    @TableField(value="contract_code")
    private String contractCode;//承包合同code
    @TableField(value="whether_upgrade")
    private Integer whetherUpgrade;//是否升版文件(0 否 1 是)
    @TableField(value="dc_drwgrp_info_name")
    private String dcDrwgrpInfoName; // 卷册名称
    @TableField(value="statistical_results")
    private String statisticalResults; // 统计成果文件名称
    @TableField(value="statistical_results_file")
    private String statisticalResultsFile; // 统计成果文件id
    @TableField(value="drwgrp_vsn")
    private String drwgrpVsn; // 卷册版本

    
    

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getDcDrwgrpInfoId() {
        return dcDrwgrpInfoId;
    }

    public void setDcDrwgrpInfoId(Long dcDrwgrpInfoId) {
        this.dcDrwgrpInfoId = dcDrwgrpInfoId;
    }
    public Long getBudgeId() {
        return budgeId;
    }

    public void setBudgeId(Long budgeId) {
        this.budgeId = budgeId;
    }
    public Long getSettlementCenterMajor() {
        return settlementCenterMajor;
    }

    public void setSettlementCenterMajor(Long settlementCenterMajor) {
        this.settlementCenterMajor = settlementCenterMajor;
    }
    public BigDecimal getStatisticalOutput() {
        return statisticalOutput;
    }

    public void setStatisticalOutput(BigDecimal statisticalOutput) {
        this.statisticalOutput = statisticalOutput;
    }
    public Long getDiscriminateState() {
        return discriminateState;
    }

    public void setDiscriminateState(Long discriminateState) {
        this.discriminateState = discriminateState;
    }
    public Date getFirstNodeTime() {
        return firstNodeTime;
    }

    public void setFirstNodeTime(Date firstNodeTime) {
        this.firstNodeTime = firstNodeTime;
    }
    public Date getSecondNodeTime() {
        return secondNodeTime;
    }

    public void setSecondNodeTime(Date secondNodeTime) {
        this.secondNodeTime = secondNodeTime;
    }
    public Date getThirdNodeTime() {
        return thirdNodeTime;
    }

    public void setThirdNodeTime(Date thirdNodeTime) {
        this.thirdNodeTime = thirdNodeTime;
    }
    public Date getFourthNodeTime() {
        return fourthNodeTime;
    }

    public void setFourthNodeTime(Date fourthNodeTime) {
        this.fourthNodeTime = fourthNodeTime;
    }
    public Date getFifthNodeTime() {
        return fifthNodeTime;
    }

    public void setFifthNodeTime(Date fifthNodeTime) {
        this.fifthNodeTime = fifthNodeTime;
    }
    public Date getSixthNodeTime() {
        return sixthNodeTime;
    }

    public void setSixthNodeTime(Date sixthNodeTime) {
        this.sixthNodeTime = sixthNodeTime;
    }
    public Date getSeventhNodeTime() {
        return seventhNodeTime;
    }

    public void setSeventhNodeTime(Date seventhNodeTime) {
        this.seventhNodeTime = seventhNodeTime;
    }
    public Long getFirstNodeUserId() {
        return firstNodeUserId;
    }

    public void setFirstNodeUserId(Long firstNodeUserId) {
        this.firstNodeUserId = firstNodeUserId;
    }
    public Long getSecondNodeUserId() {
        return secondNodeUserId;
    }

    public void setSecondNodeUserId(Long secondNodeUserId) {
        this.secondNodeUserId = secondNodeUserId;
    }
    public Long getThirdNodeUserId() {
        return thirdNodeUserId;
    }

    public void setThirdNodeUserId(Long thirdNodeUserId) {
        this.thirdNodeUserId = thirdNodeUserId;
    }
    public Long getFourthNodeUserId() {
        return fourthNodeUserId;
    }

    public void setFourthNodeUserId(Long fourthNodeUserId) {
        this.fourthNodeUserId = fourthNodeUserId;
    }
    public Long getFifthNodeUserId() {
        return fifthNodeUserId;
    }

    public void setFifthNodeUserId(Long fifthNodeUserId) {
        this.fifthNodeUserId = fifthNodeUserId;
    }
    public Long getSixthNodeUserId() {
        return sixthNodeUserId;
    }

    public void setSixthNodeUserId(Long sixthNodeUserId) {
        this.sixthNodeUserId = sixthNodeUserId;
    }
    public Long getSeventhNodeUserId() {
        return seventhNodeUserId;
    }

    public void setSeventhNodeUserId(Long seventhNodeUserId) {
        this.seventhNodeUserId = seventhNodeUserId;
    }
    public Long getCreateDeptId() {
        return createDeptId;
    }

    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    public Long getSubitem() {
        return subitem;
    }

    public void setSubitem(Long subitem) {
        this.subitem = subitem;
    }
    public String getSubitemName() {
        return subitemName;
    }

    public void setSubitemName(String subitemName) {
        this.subitemName = subitemName;
    }
    public String getFlowState() {
        return flowState;
    }

    public void setFlowState(String flowState) {
        this.flowState = flowState;
    }
    public String getFlowStateName() {
        return flowStateName;
    }

    public void setFlowStateName(String flowStateName) {
        this.flowStateName = flowStateName;
    }
    public Date getDesiredTime() {
        return desiredTime;
    }

    public void setDesiredTime(Date desiredTime) {
        this.desiredTime = desiredTime;
    }

    public Date getEighthNodeTime() {
        return eighthNodeTime;
    }

    public void setEighthNodeTime(Date eighthNodeTime) {
        this.eighthNodeTime = eighthNodeTime;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getDcDrwgrpInfoCode() {
        return dcDrwgrpInfoCode;
    }

    public void setDcDrwgrpInfoCode(String dcDrwgrpInfoCode) {
        this.dcDrwgrpInfoCode = dcDrwgrpInfoCode;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public Integer getWhetherUpgrade() {
        return whetherUpgrade;
    }

    public void setWhetherUpgrade(Integer whetherUpgrade) {
        this.whetherUpgrade = whetherUpgrade;
    }

    public String getDcDrwgrpInfoName() {
        return dcDrwgrpInfoName;
    }

    public void setDcDrwgrpInfoName(String dcDrwgrpInfoName) {
        this.dcDrwgrpInfoName = dcDrwgrpInfoName;
    }

    public String getFirstNodeUserName() {
        return firstNodeUserName;
    }

    public void setFirstNodeUserName(String firstNodeUserName) {
        this.firstNodeUserName = firstNodeUserName;
    }

    public String getSecondNodeUserName() {
        return secondNodeUserName;
    }

    public void setSecondNodeUserName(String secondNodeUserName) {
        this.secondNodeUserName = secondNodeUserName;
    }

    public String getThirdNodeUserName() {
        return thirdNodeUserName;
    }

    public void setThirdNodeUserName(String thirdNodeUserName) {
        this.thirdNodeUserName = thirdNodeUserName;
    }

    public String getFourthNodeUserName() {
        return fourthNodeUserName;
    }

    public void setFourthNodeUserName(String fourthNodeUserName) {
        this.fourthNodeUserName = fourthNodeUserName;
    }

    public String getFifthNodeUserName() {
        return fifthNodeUserName;
    }

    public void setFifthNodeUserName(String fifthNodeUserName) {
        this.fifthNodeUserName = fifthNodeUserName;
    }

    public String getSixthNodeUserName() {
        return sixthNodeUserName;
    }

    public void setSixthNodeUserName(String sixthNodeUserName) {
        this.sixthNodeUserName = sixthNodeUserName;
    }

    public String getSeventhNodeUserName() {
        return seventhNodeUserName;
    }

    public void setSeventhNodeUserName(String seventhNodeUserName) {
        this.seventhNodeUserName = seventhNodeUserName;
    }

    public String getStatisticalResults() {
        return statisticalResults;
    }

    public void setStatisticalResults(String statisticalResults) {
        this.statisticalResults = statisticalResults;
    }

    public String getStatisticalResultsFile() {
        return statisticalResultsFile;
    }

    public void setStatisticalResultsFile(String statisticalResultsFile) {
        this.statisticalResultsFile = statisticalResultsFile;
    }

    public String getDrwgrpVsn() {
        return drwgrpVsn;
    }

    public void setDrwgrpVsn(String drwgrpVsn) {
        this.drwgrpVsn = drwgrpVsn;
    }
}
